Przycisk "Wstaw tabelę"

Przycisk "Wstaw tabelę" | Spis treści

Przycisk "Wstaw tabelę" otwiera okno pokazane poniżej. Można w ten sposób stworzyć nową tabelę.
Opis pól:

Kolumny | Liczba kolumn w tabeli.
Wiersze | Liczba wierszy w tabeli.
Cellpadding | Odległość akapitu od krawędzi komórki tabeli.
Cellspacing | Szerokość krawędzi komórek tabeli.
Wyrównanie | Wyrównanie tabeli.
Krawędzie | Grubość krawędzi tabeli.
Szerokość | Szerokość tabeli w pikselach.
Wysokość | Wysokość tabeli w pikselach.
Klasa | Styl lub klasa CSS tabeli.

Idź do: Spis treści | Do góry